@@ -7,9 +7,9 @@ use warnings;
 use Scalar::Util qw(blessed);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-09-24'; # DATE
+our $DATE = '2022-09-09'; # DATE
 our $DIST = 'App-dateseq'; # DIST
-our $VERSION = '0.106'; # VERSION
+our $VERSION = '0.108'; # VERSION
 
 our %SPEC;
 
@@ -96,10 +96,23 @@ _
             schema => 'str*',
         },
         limit => {
-            summary => 'Only generate a certain amount of numbers',
+            summary => 'Only generate a certain amount of dates',
             schema => ['posint*'],
             cmdline_aliases => {n=>{}},
         },
+        random => {
+            summary => 'Instead of incrementing/decrementing monotonically, generate random date between --to and --from',
+            schema => ['true*'],
+            description => <<'_',
+
+If you specify this, you have to specify `--to` *and* `--from`.
+
+Also, currently, if you also specify `--limit-yearly` or `--limit-monthly`, the
+script may hang because it runs out of dates, so be careful when specifying
+these options combined.
+
+_
+        },
         limit_yearly => {
             summary => 'Only output at most this number of dates for each year',
             schema => ['posint*'],
@@ -330,6 +343,10 @@ sub dateseq {
     $args{increment} //= DateTime::Duration->new(days=>1);
     my $reverse = $args{reverse};
 
+    my $random = $args{random};
+    return [412, "If you specify --random, you must also specify --from *and* --to"]
+        if $random && !$args{to};
+
     my $formatter;
     if (my $cl = $args{format_class}) {
         $cl = "DateTime::Format::$cl";
@@ -434,7 +451,14 @@ sub dateseq {
         }
     };
 
-    if (defined $args{to} || defined $args{limit}) {
+    my $num_secs;
+    if ($random) {
+        my $epoch_from = $args{from}->epoch;
+        my $epoch_to   = $args{to}->epoch;
+        $num_secs = $epoch_to-$epoch_from;
+    }
+
+    if ((defined $args{to} || defined $args{limit}) && !$random) {
         my @res;
         push @res, $args{header} if $args{header};
         my $dt = $args{from}->clone;
@@ -451,18 +475,24 @@ sub dateseq {
         return [200, "OK", \@res];
     } else {
         # stream
+        # --random always goes here
         my $dt = $args{from}->clone;
         my $j  = $args{header} ? -1 : 0;
         my $next_dt;
         #my $finish;
         my $func0 = sub {
             #return undef if $finish;
-            $dt = $next_dt if $j++ > 0;
             return $args{header} if $j == 0 && $args{header};
-            $next_dt = $reverse ?
-                $dt - $args{increment} : $dt + $args{increment};
-            #$finish = 1 if ...
-            return $dt;
+            if ($random) {
+                $dt = $args{from}->clone->add(seconds => $num_secs * rand());
+                return $dt;
+            } else {
+                $dt = $next_dt if $j++ > 0;
+                $next_dt = $reverse ?
+                    $dt - $args{increment} : $dt + $args{increment};
+                #$finish = 1 if ...
+                return $dt;
+            }
         };
         my $filtered_func = sub {
             while (1) {
@@ -491,7 +521,7 @@ App::dateseq - Generate a sequence of dates
 
 =head1 VERSION
 
-This document describes version 0.106 of App::dateseq (from Perl distribution App-dateseq), released on 2021-09-24.
+This document describes version 0.108 of App::dateseq (from Perl distribution App-dateseq), released on 2022-09-09.
 
 =head1 FUNCTIONS
 
@@ -567,7 +597,7 @@ Only show dates with these month numbers.
 
 =item * B<limit> => I<posint>
 
-Only generate a certain amount of numbers.
+Only generate a certain amount of dates.
 
 =item * B<limit_monthly> => I<posint>
 
@@ -577,6 +607,16 @@ Only output at most this number of dates for each month.
 
 Only output at most this number of dates for each year.
 
+=item * B<random> => I<true>
+
+Instead of incrementingE<sol>decrementing monotonically, generate random date between --to and --from.
+
+If you specify this, you have to specify C<--to> I<and> C<--from>.
+
+Also, currently, if you also specify C<--limit-yearly> or C<--limit-monthly>, the
+script may hang because it runs out of dates, so be careful when specifying
+these options combined.
+
 =item * B<reverse> => I<true>
 
 Decrement instead of increment.
@@ -646,13 +686,14 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2019, 2016, 2015 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2022, 2021, 2020, 2019, 2016, 2015 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
